import qr from "../../utils/qrcode/qrcode";
import { h } from "@stencil/core";
import { ErrorCorrectionLevel } from "./enums";
const QRC = qr.QrCode;
export class QRCode {
    constructor() {
        this.url = undefined;
        this.level = ErrorCorrectionLevel.M;
        this.class = '';
        this.color = 'black';
    }
    render() {
        const getEcc = (ecc) => {
            ecc = ecc.toUpperCase();
            if (ecc === 'L')
                return QRC.Ecc.LOW;
            if (ecc === 'M')
                return QRC.Ecc.MEDIUM;
            if (ecc === 'Q')
                return QRC.Ecc.QUARTILE;
            return QRC.Ecc.HIGH;
        };
        const ecc = getEcc(this.level);
        const qr = QRC.encodeText(this.url, ecc);
        const qrcode = qr.svgObject();
        return (h("svg", { class: this.class, viewBox: `0 0 ${qrcode.size} ${qrcode.size}` }, h("path", { d: qrcode.path, fill: this.color })));
    }
    static get is() { return "qr-code"; }
    static get properties() {
        return {
            "url": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": true,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "url",
                "reflect": false
            },
            "level": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "ErrorCorrectionLevel",
                    "resolved": "ErrorCorrectionLevel.H | ErrorCorrectionLevel.L | ErrorCorrectionLevel.M | ErrorCorrectionLevel.Q",
                    "references": {
                        "ErrorCorrectionLevel": {
                            "location": "import",
                            "path": "./enums",
                            "id": "src/components/zero-account/enums.ts::ErrorCorrectionLevel"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "level",
                "reflect": false,
                "defaultValue": "ErrorCorrectionLevel.M"
            },
            "class": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "class",
                "reflect": false,
                "defaultValue": "''"
            },
            "color": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "color",
                "reflect": false,
                "defaultValue": "'black'"
            }
        };
    }
}
//# sourceMappingURL=qrcode.js.map
